ProcessContext

Trait ProcessContext 

pub trait ProcessContext {
    // Required method
    fn parameters(&self) -> &impl BufferStates;
}
A trait for metadata during an audio processing call

Required Methods

fn parameters(&self) -> &impl BufferStates

Parameter states for this call

In order to consume the parameters, you can use the crate::pzip macro to convert the parameters into an iterator of tuples that represent the state of the parameters at each sample.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors